# Modified by SFMAKMODIFIER Ver 1.0
#============================================================================
#  Name:
#    $(TARGET).MAK
#
#  Description:
#    Makefile to build the $(TARGET) downloadable module.
#
#   The following nmake targets are available in this makefile:
#
#     all           - make .elf and .mod image files (default)
#     clean         - delete object directory and image files
#     filename.o    - make object file
#
#   The above targets can be made with the following command:
#
#     nmake /f $(TARGET).mak [target]
#
#  Assumptions:
#    1. The environment variable ADSHOME is set to the root directory of the
#       arm tools.
#    2. The version of ADS is 1.2 or above.
#
#  Notes:
#    None.
#
#
#        Copyright  2000-2001 QUALCOMM Incorporated.
#               All Rights Reserved.
#            QUALCOMM Proprietary/GTDR
#
#----------------------------------------------------------------------------
#============================================================================
SF_HOME        =$(SFHOME)
ARM_HOME       =$(ARMHOME)
BREW_HOME      =$(BREWDIR)
TARGET         =pself2
OBJS           =INFORM~1.o INPUTW~1.o pself2.o SAXPAR~1.o SGRERR~1.o SGRLIS~1.o SGRNET~1.o SGRSOF~1.o SGRSOF~2.o SHELFW~1.o TITLEW~1.o 
APP_INCLUDES   = -I "$(BREWDIR)\inc" -I "$(SF_HOME)\Include"

#-------------------------------------------------------------------------------
# Target file name and type definitions
#-------------------------------------------------------------------------------

EXETYPE    = elf                # Target image file format
MODULE     = mod                # Downloadable module extension

#-------------------------------------------------------------------------------
# Target compile time symbol definitions
#
# Tells the SDK source stuffs that we're building a dynamic app.
#-------------------------------------------------------------------------------

# DYNAPP          = -DDYNAMIC_APP
DYNAPP          = -DDYNAMIC_APP


#-------------------------------------------------------------------------------
# Software tool and environment definitions
#-------------------------------------------------------------------------------

AEESRCPATH = $(BREW_HOME)\src
AEEINCPATH = $(BREW_HOME)\inc

ARMBIN = $(ARM_HOME)\bin        # ARM ADS application directory
ARMINC = $(ARM_HOME)\include    # ARM ADS include file directory
ARMLIB = $(ARM_HOME)\lib        # ARM ADS library directory

ARMCC    = $(ARMBIN)\armcc      # ARM ADS ARM 32-bit inst. set ANSI CPP compiler
ARMCPP   = $(ARMBIN)\armcpp     # ARM ADS ARM 32-bit inst. set ANSI CPP compiler
LD       = $(ARMBIN)\armlink     # ARM ADS linker
HEXTOOL  = $(ARMBIN)\fromelf     # ARM ADS utility to create hex file from image

OBJ_CMD    = -o                 # Command line option to specify output filename

#-------------------------------------------------------------------------------
# Processor architecture options
#-------------------------------------------------------------------------------

CPU = -cpu ARM7TDMI             # ARM7TDMI target processor

#-------------------------------------------------------------------------------
# ARM Procedure Call Standard (APCS) options
#-------------------------------------------------------------------------------

ROPI     = ropi                 # Read-Only(code) Position independence
INTERWRK = interwork            # Allow ARM-Thumb interworking

APCS = -apcs /$(ROPI)/$(INTERWRK)/norwpi

#-------------------------------------------------------------------------------
# Additional compile time error checking options
#-------------------------------------------------------------------------------

CHK = -fa                       # Check for data flow anomolies

#-------------------------------------------------------------------------------
# Compiler output options
#-------------------------------------------------------------------------------

OUT = -c                        # Object file output only

#-------------------------------------------------------------------------------
# Compiler/assembler debug options
#-------------------------------------------------------------------------------

# DBG = -g                        # Enable debug
DBG = -g-

#-------------------------------------------------------------------------------
# Compiler optimization options
#-------------------------------------------------------------------------------

# OPT = -Ospace -O2               # Full compiler optimization for space
OPT = -Otime -O2

#-------------------------------------------------------------------------------
# Compiler code generation options
#-------------------------------------------------------------------------------

END = -littleend                # Compile for little endian memory architecture
ZA  = -zo                       # LDR may only access 32-bit aligned addresses

CODE = $(END) $(ZA)


#-------------------------------------------------------------------------------
# Include file search path options
#-------------------------------------------------------------------------------

INC = -I. -I$(AEEINCPATH) $(APP_INCLUDES)


#-------------------------------------------------------------------------------
# Compiler pragma emulation options
#-------------------------------------------------------------------------------


#-------------------------------------------------------------------------------
# Linker options
#-------------------------------------------------------------------------------

LINK_CMD = -o                    #Command line option to specify output file
                                 #on linking

ROPILINK = -ropi                 #Link image as Read-Only Position Independent

LINK_ORDER = -first AEEMod_Load

#-------------------------------------------------------------------------------
# HEXTOOL options
#-------------------------------------------------------------------------------

BINFORMAT = -bin


#-------------------------------------------------------------------------------
# Compiler flag definitions
#-------------------------------------------------------------------------------

CFLAGS0 = $(OUT) $(DYNAPP) $(CPU) $(APCS) $(CODE) $(CHK) $(DBG)
CFLAGS  = $(CFLAGS0) $(OPT)

#-------------------------------------------------------------------------------
# Linker flag definitions
#-------------------------------------------------------------------------------

# the -entry flag is not really needed, but it keeps the linker from reporting
# warning L6305W (no entry point).  The address
# LFLAGS = $(ROPILINK) -rwpi -entry 0x8000#
LFLAGS = $(ROPILINK) -rwpi -entry AEEMod_Load#0x8000#


#----------------------------------------------------------------------------
# Default target
#----------------------------------------------------------------------------

all :  $(TARGET).$(MODULE)

#----------------------------------------------------------------------------
# Clean target
#----------------------------------------------------------------------------

# The object subdirectory, target image file, and target hex file are deleted.

clean :
	@echo ---------------------------------------------------------------
	@echo CLEAN
	-del /f $(OBJS)
	-del /f $(TARGET).$(EXETYPE)
	-del /f $(TARGET).$(MODULE)
	@echo ---------------------------------------------------------------

#============================================================================
#                           DEFAULT SUFFIX RULES
#============================================================================

# The following are the default suffix rules used to compile all objects that
# are not specifically included in one of the module specific rules defined
# in the next section.

# The following macros are used to specify the output object file, MSG_FILE
# symbol definition and input source file on the compile line in the rules
# defined below.

SRC_CPP_FILE = $(@F:.o=.cpp)      # Input source file specification
SRC_C_FILE   = $(@F:.o=.c)      # Input source file specification
OBJ_FILE = $(OBJ_CMD) $(@F)   # Output object file specification

.SUFFIXES :
.SUFFIXES : .o .dep .c .cpp

#--------------------------------------------------------------------------
# C code inference rules
#----------------------------------------------------------------------------

.cpp.o:
	@echo ---------------------------------------------------------------
	@echo OBJECT $(@F)
	$(ARMCPP) $(CFLAGS) $(INC) $(OBJ_FILE) $(SRC_CPP_FILE)
	@echo ---------------------------------------------------------------


{$(AEESRCPATH)}.c.o:
	@echo ---------------------------------------------------------------
	@echo OBJECT $(@F)
	$(ARMCC) $(CFLAGS) $(INC) $(OBJ_FILE) $(AEESRCPATH)\$(SRC_C_FILE)
	@echo ---------------------------------------------------------------


#===============================================================================
#                           MODULE SPECIFIC RULES
#===============================================================================

APP_OBJS =  $(OBJS) "$(SF_HOME)\Library\SophiaFrameworkBrew400JpnRVCTB12.a"

#----------------------------------------------------------------------------
# Lib file targets
#----------------------------------------------------------------------------

$(TARGET).$(MODULE) : $(TARGET).$(EXETYPE)
	@echo ---------------------------------------------------------------
	@echo TARGET $@
	$(HEXTOOL)  $(TARGET).$(EXETYPE) $(BINFORMAT) -output $(TARGET).$(MODULE)

$(TARGET).$(EXETYPE) : $(APP_OBJS)
	@echo ---------------------------------------------------------------
	@echo TARGET $@
	$(LD) $(LINK_CMD) $(TARGET).$(EXETYPE) $(LFLAGS) $(APP_OBJS) $(LINK_ORDER)

#----------------------------------------------------------------------------
# Applet Specific Rules
#----------------------------------------------------------------------------


RULE1 = .
{$(RULE1)}.c.o:
	@echo ---------------------------------------------------------------
	@echo OBJECT $(@F)
	$(ARMCC) $(CFLAGS) $(INC) $(OBJ_FILE)  $(RULE1)\$(SRC_C_FILE)
	@echo ---------------------------------------------------------------


# --------------------------------------------
# DEPENDENCY LIST, DO NOT EDIT BELOW THIS LINE
# --------------------------------------------


inform~1.o:	inform~1.cpp
inform~1.o:	pself2.hpp
inform~1.o:	pself2.bid
inform~1.o:	informationwindow.hpp
inform~1.o:	sgrerrordialogset.hpp
inform~1.o:	saxparser.hpp
inform~1.o:	sgrsoftkeywindow.hpp
inform~1.o:	sgrsoftkeytoolbox.hpp
inform~1.o:	pself2_res.h
inform~1.o:	saxparser.hpp
inputw~1.o:	inputw~1.cpp
inputw~1.o:	inputwindow.hpp
inputw~1.o:	sgrnetworkdialogset.hpp
inputw~1.o:	sgrsoftkeytoolbox.hpp
inputw~1.o:	sgrerrordialogset.hpp
inputw~1.o:	saxparser.hpp
inputw~1.o:	sgrerrordialogset.hpp
inputw~1.o:	informationwindow.hpp
inputw~1.o:	sgrerrordialogset.hpp
inputw~1.o:	saxparser.hpp
inputw~1.o:	pself2.hpp
inputw~1.o:	pself2.bid
inputw~1.o:	sgrsoftkeywindow.hpp
inputw~1.o:	sgrsoftkeytoolbox.hpp
inputw~1.o:	pself2_res.h
inputw~1.o:	saxparser.hpp
pself2.o:	pself2.cpp
pself2.o:	pself2.hpp
pself2.o:	pself2.bid
pself2.o:	pself2_res.h
pself2.o:	titlewindow.hpp
pself2.o:	sgrsoftkeywindow.hpp
pself2.o:	sgrsoftkeytoolbox.hpp
saxpar~1.o:	saxpar~1.cpp
saxpar~1.o:	saxparser.hpp
saxpar~1.o:	pself2_res.h
sgrerr~1.o:	sgrerr~1.cpp
sgrerr~1.o:	sgrerrordialogset.hpp
sgrerr~1.o:	sgrsoftkeytoolbox.hpp
sgrlis~1.o:	sgrlis~1.cpp
sgrlis~1.o:	sgrlistboxcontrol.hpp
sgrlis~1.o:	pself2_res.h
sgrnet~1.o:	sgrnet~1.cpp
sgrnet~1.o:	pself2.hpp
sgrnet~1.o:	pself2.bid
sgrnet~1.o:	sgrnetworkdialogset.hpp
sgrnet~1.o:	sgrsoftkeytoolbox.hpp
sgrnet~1.o:	sgrerrordialogset.hpp
sgrnet~1.o:	pself2_res.h
sgrsof~1.o:	sgrsof~1.cpp
sgrsof~1.o:	sgrsoftkeytoolbox.hpp
sgrsof~1.o:	sgrsoftkeywindow.hpp
sgrsof~2.o:	sgrsof~2.cpp
sgrsof~2.o:	sgrsoftkeywindow.hpp
shelfw~1.o:	shelfw~1.cpp
shelfw~1.o:	pself2.hpp
shelfw~1.o:	pself2.bid
shelfw~1.o:	pself2_res.h
shelfw~1.o:	shelfwindow.hpp
shelfw~1.o:	sgrlistboxcontrol.hpp
shelfw~1.o:	saxparser.hpp
shelfw~1.o:	sgrsoftkeywindow.hpp
shelfw~1.o:	informationwindow.hpp
shelfw~1.o:	sgrerrordialogset.hpp
shelfw~1.o:	saxparser.hpp
shelfw~1.o:	sgrsoftkeytoolbox.hpp
shelfw~1.o:	saxparser.hpp
titlew~1.o:	titlew~1.cpp
titlew~1.o:	titlewindow.hpp
titlew~1.o:	shelfwindow.hpp
titlew~1.o:	sgrlistboxcontrol.hpp
titlew~1.o:	saxparser.hpp
titlew~1.o:	pself2.hpp
titlew~1.o:	pself2.bid
titlew~1.o:	sgrsoftkeywindow.hpp
titlew~1.o:	sgrsoftkeytoolbox.hpp
titlew~1.o:	inputwindow.hpp
titlew~1.o:	sgrnetworkdialogset.hpp
titlew~1.o:	sgrsoftkeytoolbox.hpp
titlew~1.o:	sgrerrordialogset.hpp
titlew~1.o:	saxparser.hpp
titlew~1.o:	sgrerrordialogset.hpp
titlew~1.o:	informationwindow.hpp
titlew~1.o:	sgrerrordialogset.hpp
titlew~1.o:	saxparser.hpp
titlew~1.o:	pself2_res.h
titlew~1.o:	saxparser.hpp
